# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/nlp/v1/nlp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/nlp/v1/nlp.proto',
  package='arg_services.nlp.v1',
  syntax='proto3',
  serialized_options=b'\n&de.uni_trier.recap.arg_services.nlp.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x61rg_services/nlp/v1/nlp.proto\x12\x13\x61rg_services.nlp.v1\"\xb3\x01\n\tNlpConfig\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x13\n\x0bspacy_model\x18\x02 \x01(\t\x12=\n\x10\x65mbedding_models\x18\x03 \x03(\x0b\x32#.arg_services.nlp.v1.EmbeddingModel\x12@\n\x11similarity_method\x18\x04 \x01(\x0e\x32%.arg_services.nlp.v1.SimilarityMethod\"z\n\x13SimilaritiesRequest\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\x33\n\x0btext_tuples\x18\x02 \x03(\x0b\x32\x1e.arg_services.nlp.v1.TextTuple\",\n\x14SimilaritiesResponse\x12\x14\n\x0csimilarities\x18\x01 \x03(\x01\")\n\tTextTuple\x12\r\n\x05text1\x18\x01 \x01(\t\x12\r\n\x05text2\x18\x02 \x01(\t\"\xd9\x01\n\rDocBinRequest\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\r\n\x05texts\x18\x02 \x03(\t\x12\x12\n\nattributes\x18\x03 \x03(\t\x12\x15\n\rno_attributes\x18\x04 \x01(\x08\x12\r\n\x05pipes\x18\x05 \x03(\t\x12\x10\n\x08no_pipes\x18\x06 \x01(\x08\x12=\n\x10\x65mbedding_levels\x18\x07 \x03(\x0e\x32#.arg_services.nlp.v1.EmbeddingLevel\" \n\x0e\x44ocBinResponse\x12\x0e\n\x06\x64ocbin\x18\x01 \x01(\x0c\"\x8e\x01\n\x0eVectorsRequest\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\r\n\x05texts\x18\x02 \x03(\t\x12=\n\x10\x65mbedding_levels\x18\x03 \x03(\x0e\x32#.arg_services.nlp.v1.EmbeddingLevel\"G\n\x0fVectorsResponse\x12\x34\n\x07vectors\x18\x01 \x03(\x0b\x32#.arg_services.nlp.v1.VectorResponse\"\x9c\x01\n\x0eVectorResponse\x12-\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x1b.arg_services.nlp.v1.Vector\x12+\n\x06tokens\x18\x02 \x03(\x0b\x32\x1b.arg_services.nlp.v1.Vector\x12.\n\tsentences\x18\x03 \x03(\x0b\x32\x1b.arg_services.nlp.v1.Vector\"\x18\n\x06Vector\x12\x0e\n\x06vector\x18\x01 \x03(\x01\"\x8b\x01\n\x0e\x45mbeddingModel\x12\x36\n\nmodel_type\x18\x01 \x01(\x0e\x32\".arg_services.nlp.v1.EmbeddingType\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12-\n\x07pooling\x18\x03 \x01(\x0e\x32\x1c.arg_services.nlp.v1.Pooling*\xe0\x02\n\x10SimilarityMethod\x12!\n\x1dSIMILARITY_METHOD_UNSPECIFIED\x10\x00\x12\x1c\n\x18SIMILARITY_METHOD_COSINE\x10\x01\x12%\n!SIMILARITY_METHOD_DYNAMAX_JACCARD\x10\x02\x12%\n!SIMILARITY_METHOD_MAXPOOL_JACCARD\x10\x03\x12\"\n\x1eSIMILARITY_METHOD_DYNAMAX_DICE\x10\x04\x12$\n SIMILARITY_METHOD_DYNAMAX_OTSUKA\x10\x05\x12\x19\n\x15SIMILARITY_METHOD_WMD\x10\x06\x12\x1a\n\x16SIMILARITY_METHOD_EDIT\x10\x07\x12\x1d\n\x19SIMILARITY_METHOD_JACCARD\x10\x08\x12\x1d\n\x19SIMILARITY_METHOD_ANGULAR\x10\t*\x8a\x01\n\x0e\x45mbeddingLevel\x12\x1f\n\x1b\x45MBEDDING_LEVEL_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45MBEDDING_LEVEL_DOCUMENT\x10\x01\x12\x1a\n\x16\x45MBEDDING_LEVEL_TOKENS\x10\x02\x12\x1d\n\x19\x45MBEDDING_LEVEL_SENTENCES\x10\x03*\xc6\x01\n\x07Pooling\x12\x17\n\x13POOLING_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOOLING_MEAN\x10\x01\x12\x0f\n\x0bPOOLING_MAX\x10\x02\x12\x0f\n\x0bPOOLING_MIN\x10\x03\x12\x0f\n\x0bPOOLING_SUM\x10\x04\x12\x11\n\rPOOLING_FIRST\x10\x05\x12\x10\n\x0cPOOLING_LAST\x10\x06\x12\x12\n\x0ePOOLING_MEDIAN\x10\x07\x12\x11\n\rPOOLING_GMEAN\x10\x08\x12\x11\n\rPOOLING_HMEAN\x10\t*{\n\rEmbeddingType\x12\x1e\n\x1a\x45MBEDDING_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45MBEDDING_TYPE_SPACY\x10\x01\x12\x16\n\x12\x45MBEDDING_TYPE_USE\x10\x02\x12\x18\n\x14\x45MBEDDING_TYPE_SBERT\x10\x03\x32\x9a\x02\n\nNlpService\x12Q\n\x06\x44ocBin\x12\".arg_services.nlp.v1.DocBinRequest\x1a#.arg_services.nlp.v1.DocBinResponse\x12T\n\x07Vectors\x12#.arg_services.nlp.v1.VectorsRequest\x1a$.arg_services.nlp.v1.VectorsResponse\x12\x63\n\x0cSimilarities\x12(.arg_services.nlp.v1.SimilaritiesRequest\x1a).arg_services.nlp.v1.SimilaritiesResponseB(\n&de.uni_trier.recap.arg_services.nlp.v1b\x06proto3'
)

_SIMILARITYMETHOD = _descriptor.EnumDescriptor(
  name='SimilarityMethod',
  full_name='arg_services.nlp.v1.SimilarityMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_COSINE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_DYNAMAX_JACCARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_MAXPOOL_JACCARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_DYNAMAX_DICE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_DYNAMAX_OTSUKA', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_WMD', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_EDIT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_JACCARD', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_ANGULAR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1249,
  serialized_end=1601,
)
_sym_db.RegisterEnumDescriptor(_SIMILARITYMETHOD)

SimilarityMethod = enum_type_wrapper.EnumTypeWrapper(_SIMILARITYMETHOD)
_EMBEDDINGLEVEL = _descriptor.EnumDescriptor(
  name='EmbeddingLevel',
  full_name='arg_services.nlp.v1.EmbeddingLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_DOCUMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_TOKENS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_SENTENCES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1604,
  serialized_end=1742,
)
_sym_db.RegisterEnumDescriptor(_EMBEDDINGLEVEL)

EmbeddingLevel = enum_type_wrapper.EnumTypeWrapper(_EMBEDDINGLEVEL)
_POOLING = _descriptor.EnumDescriptor(
  name='Pooling',
  full_name='arg_services.nlp.v1.Pooling',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POOLING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MEAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MAX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MIN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_SUM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_FIRST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_LAST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MEDIAN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_GMEAN', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_HMEAN', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1745,
  serialized_end=1943,
)
_sym_db.RegisterEnumDescriptor(_POOLING)

Pooling = enum_type_wrapper.EnumTypeWrapper(_POOLING)
_EMBEDDINGTYPE = _descriptor.EnumDescriptor(
  name='EmbeddingType',
  full_name='arg_services.nlp.v1.EmbeddingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_SPACY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_USE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_SBERT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1945,
  serialized_end=2068,
)
_sym_db.RegisterEnumDescriptor(_EMBEDDINGTYPE)

EmbeddingType = enum_type_wrapper.EnumTypeWrapper(_EMBEDDINGTYPE)
SIMILARITY_METHOD_UNSPECIFIED = 0
SIMILARITY_METHOD_COSINE = 1
SIMILARITY_METHOD_DYNAMAX_JACCARD = 2
SIMILARITY_METHOD_MAXPOOL_JACCARD = 3
SIMILARITY_METHOD_DYNAMAX_DICE = 4
SIMILARITY_METHOD_DYNAMAX_OTSUKA = 5
SIMILARITY_METHOD_WMD = 6
SIMILARITY_METHOD_EDIT = 7
SIMILARITY_METHOD_JACCARD = 8
SIMILARITY_METHOD_ANGULAR = 9
EMBEDDING_LEVEL_UNSPECIFIED = 0
EMBEDDING_LEVEL_DOCUMENT = 1
EMBEDDING_LEVEL_TOKENS = 2
EMBEDDING_LEVEL_SENTENCES = 3
POOLING_UNSPECIFIED = 0
POOLING_MEAN = 1
POOLING_MAX = 2
POOLING_MIN = 3
POOLING_SUM = 4
POOLING_FIRST = 5
POOLING_LAST = 6
POOLING_MEDIAN = 7
POOLING_GMEAN = 8
POOLING_HMEAN = 9
EMBEDDING_TYPE_UNSPECIFIED = 0
EMBEDDING_TYPE_SPACY = 1
EMBEDDING_TYPE_USE = 2
EMBEDDING_TYPE_SBERT = 3



_NLPCONFIG = _descriptor.Descriptor(
  name='NlpConfig',
  full_name='arg_services.nlp.v1.NlpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='arg_services.nlp.v1.NlpConfig.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spacy_model', full_name='arg_services.nlp.v1.NlpConfig.spacy_model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embedding_models', full_name='arg_services.nlp.v1.NlpConfig.embedding_models', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='similarity_method', full_name='arg_services.nlp.v1.NlpConfig.similarity_method', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=234,
)


_SIMILARITIESREQUEST = _descriptor.Descriptor(
  name='SimilaritiesRequest',
  full_name='arg_services.nlp.v1.SimilaritiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.nlp.v1.SimilaritiesRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_tuples', full_name='arg_services.nlp.v1.SimilaritiesRequest.text_tuples', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=358,
)


_SIMILARITIESRESPONSE = _descriptor.Descriptor(
  name='SimilaritiesResponse',
  full_name='arg_services.nlp.v1.SimilaritiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='similarities', full_name='arg_services.nlp.v1.SimilaritiesResponse.similarities', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=404,
)


_TEXTTUPLE = _descriptor.Descriptor(
  name='TextTuple',
  full_name='arg_services.nlp.v1.TextTuple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text1', full_name='arg_services.nlp.v1.TextTuple.text1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text2', full_name='arg_services.nlp.v1.TextTuple.text2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=447,
)


_DOCBINREQUEST = _descriptor.Descriptor(
  name='DocBinRequest',
  full_name='arg_services.nlp.v1.DocBinRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.nlp.v1.DocBinRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='texts', full_name='arg_services.nlp.v1.DocBinRequest.texts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='arg_services.nlp.v1.DocBinRequest.attributes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_attributes', full_name='arg_services.nlp.v1.DocBinRequest.no_attributes', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipes', full_name='arg_services.nlp.v1.DocBinRequest.pipes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_pipes', full_name='arg_services.nlp.v1.DocBinRequest.no_pipes', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embedding_levels', full_name='arg_services.nlp.v1.DocBinRequest.embedding_levels', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=667,
)


_DOCBINRESPONSE = _descriptor.Descriptor(
  name='DocBinResponse',
  full_name='arg_services.nlp.v1.DocBinResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='docbin', full_name='arg_services.nlp.v1.DocBinResponse.docbin', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=701,
)


_VECTORSREQUEST = _descriptor.Descriptor(
  name='VectorsRequest',
  full_name='arg_services.nlp.v1.VectorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.nlp.v1.VectorsRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='texts', full_name='arg_services.nlp.v1.VectorsRequest.texts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embedding_levels', full_name='arg_services.nlp.v1.VectorsRequest.embedding_levels', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=846,
)


_VECTORSRESPONSE = _descriptor.Descriptor(
  name='VectorsResponse',
  full_name='arg_services.nlp.v1.VectorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='arg_services.nlp.v1.VectorsResponse.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=919,
)


_VECTORRESPONSE = _descriptor.Descriptor(
  name='VectorResponse',
  full_name='arg_services.nlp.v1.VectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='arg_services.nlp.v1.VectorResponse.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='arg_services.nlp.v1.VectorResponse.tokens', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sentences', full_name='arg_services.nlp.v1.VectorResponse.sentences', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1078,
)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='arg_services.nlp.v1.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='arg_services.nlp.v1.Vector.vector', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1080,
  serialized_end=1104,
)


_EMBEDDINGMODEL = _descriptor.Descriptor(
  name='EmbeddingModel',
  full_name='arg_services.nlp.v1.EmbeddingModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_type', full_name='arg_services.nlp.v1.EmbeddingModel.model_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='arg_services.nlp.v1.EmbeddingModel.model_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pooling', full_name='arg_services.nlp.v1.EmbeddingModel.pooling', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1246,
)

_NLPCONFIG.fields_by_name['embedding_models'].message_type = _EMBEDDINGMODEL
_NLPCONFIG.fields_by_name['similarity_method'].enum_type = _SIMILARITYMETHOD
_SIMILARITIESREQUEST.fields_by_name['config'].message_type = _NLPCONFIG
_SIMILARITIESREQUEST.fields_by_name['text_tuples'].message_type = _TEXTTUPLE
_DOCBINREQUEST.fields_by_name['config'].message_type = _NLPCONFIG
_DOCBINREQUEST.fields_by_name['embedding_levels'].enum_type = _EMBEDDINGLEVEL
_VECTORSREQUEST.fields_by_name['config'].message_type = _NLPCONFIG
_VECTORSREQUEST.fields_by_name['embedding_levels'].enum_type = _EMBEDDINGLEVEL
_VECTORSRESPONSE.fields_by_name['vectors'].message_type = _VECTORRESPONSE
_VECTORRESPONSE.fields_by_name['document'].message_type = _VECTOR
_VECTORRESPONSE.fields_by_name['tokens'].message_type = _VECTOR
_VECTORRESPONSE.fields_by_name['sentences'].message_type = _VECTOR
_EMBEDDINGMODEL.fields_by_name['model_type'].enum_type = _EMBEDDINGTYPE
_EMBEDDINGMODEL.fields_by_name['pooling'].enum_type = _POOLING
DESCRIPTOR.message_types_by_name['NlpConfig'] = _NLPCONFIG
DESCRIPTOR.message_types_by_name['SimilaritiesRequest'] = _SIMILARITIESREQUEST
DESCRIPTOR.message_types_by_name['SimilaritiesResponse'] = _SIMILARITIESRESPONSE
DESCRIPTOR.message_types_by_name['TextTuple'] = _TEXTTUPLE
DESCRIPTOR.message_types_by_name['DocBinRequest'] = _DOCBINREQUEST
DESCRIPTOR.message_types_by_name['DocBinResponse'] = _DOCBINRESPONSE
DESCRIPTOR.message_types_by_name['VectorsRequest'] = _VECTORSREQUEST
DESCRIPTOR.message_types_by_name['VectorsResponse'] = _VECTORSRESPONSE
DESCRIPTOR.message_types_by_name['VectorResponse'] = _VECTORRESPONSE
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
DESCRIPTOR.message_types_by_name['EmbeddingModel'] = _EMBEDDINGMODEL
DESCRIPTOR.enum_types_by_name['SimilarityMethod'] = _SIMILARITYMETHOD
DESCRIPTOR.enum_types_by_name['EmbeddingLevel'] = _EMBEDDINGLEVEL
DESCRIPTOR.enum_types_by_name['Pooling'] = _POOLING
DESCRIPTOR.enum_types_by_name['EmbeddingType'] = _EMBEDDINGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NlpConfig = _reflection.GeneratedProtocolMessageType('NlpConfig', (_message.Message,), {
  'DESCRIPTOR' : _NLPCONFIG,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.NlpConfig)
  })
_sym_db.RegisterMessage(NlpConfig)

SimilaritiesRequest = _reflection.GeneratedProtocolMessageType('SimilaritiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMILARITIESREQUEST,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.SimilaritiesRequest)
  })
_sym_db.RegisterMessage(SimilaritiesRequest)

SimilaritiesResponse = _reflection.GeneratedProtocolMessageType('SimilaritiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMILARITIESRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.SimilaritiesResponse)
  })
_sym_db.RegisterMessage(SimilaritiesResponse)

TextTuple = _reflection.GeneratedProtocolMessageType('TextTuple', (_message.Message,), {
  'DESCRIPTOR' : _TEXTTUPLE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.TextTuple)
  })
_sym_db.RegisterMessage(TextTuple)

DocBinRequest = _reflection.GeneratedProtocolMessageType('DocBinRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOCBINREQUEST,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.DocBinRequest)
  })
_sym_db.RegisterMessage(DocBinRequest)

DocBinResponse = _reflection.GeneratedProtocolMessageType('DocBinResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOCBINRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.DocBinResponse)
  })
_sym_db.RegisterMessage(DocBinResponse)

VectorsRequest = _reflection.GeneratedProtocolMessageType('VectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSREQUEST,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.VectorsRequest)
  })
_sym_db.RegisterMessage(VectorsRequest)

VectorsResponse = _reflection.GeneratedProtocolMessageType('VectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.VectorsResponse)
  })
_sym_db.RegisterMessage(VectorsResponse)

VectorResponse = _reflection.GeneratedProtocolMessageType('VectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _VECTORRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.VectorResponse)
  })
_sym_db.RegisterMessage(VectorResponse)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.Vector)
  })
_sym_db.RegisterMessage(Vector)

EmbeddingModel = _reflection.GeneratedProtocolMessageType('EmbeddingModel', (_message.Message,), {
  'DESCRIPTOR' : _EMBEDDINGMODEL,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.EmbeddingModel)
  })
_sym_db.RegisterMessage(EmbeddingModel)


DESCRIPTOR._options = None

_NLPSERVICE = _descriptor.ServiceDescriptor(
  name='NlpService',
  full_name='arg_services.nlp.v1.NlpService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2071,
  serialized_end=2353,
  methods=[
  _descriptor.MethodDescriptor(
    name='DocBin',
    full_name='arg_services.nlp.v1.NlpService.DocBin',
    index=0,
    containing_service=None,
    input_type=_DOCBINREQUEST,
    output_type=_DOCBINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Vectors',
    full_name='arg_services.nlp.v1.NlpService.Vectors',
    index=1,
    containing_service=None,
    input_type=_VECTORSREQUEST,
    output_type=_VECTORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Similarities',
    full_name='arg_services.nlp.v1.NlpService.Similarities',
    index=2,
    containing_service=None,
    input_type=_SIMILARITIESREQUEST,
    output_type=_SIMILARITIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NLPSERVICE)

DESCRIPTOR.services_by_name['NlpService'] = _NLPSERVICE

# @@protoc_insertion_point(module_scope)
