# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/base/v1/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/base/v1/base.proto',
  package='arg_services.base.v1',
  syntax='proto3',
  serialized_options=b'\n\'de.uni_trier.recap.arg_services.base.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x61rg_services/base/v1/base.proto\x12\x14\x61rg_services.base.v1B)\n\'de.uni_trier.recap.arg_services.base.v1b\x06proto3'
)



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
