# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from arg_services.entailment.v1 import entailment_pb2 as arg__services_dot_entailment_dot_v1_dot_entailment__pb2


class EntailmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Entailment = channel.unary_unary(
                '/arg_services.entailment.v1.EntailmentService/Entailment',
                request_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentRequest.SerializeToString,
                response_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentResponse.FromString,
                )
        self.Entailments = channel.unary_unary(
                '/arg_services.entailment.v1.EntailmentService/Entailments',
                request_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsRequest.SerializeToString,
                response_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsResponse.FromString,
                )


class EntailmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Entailment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Entailments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EntailmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Entailment': grpc.unary_unary_rpc_method_handler(
                    servicer.Entailment,
                    request_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentRequest.FromString,
                    response_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentResponse.SerializeToString,
            ),
            'Entailments': grpc.unary_unary_rpc_method_handler(
                    servicer.Entailments,
                    request_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsRequest.FromString,
                    response_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'arg_services.entailment.v1.EntailmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EntailmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Entailment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.entailment.v1.EntailmentService/Entailment',
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentRequest.SerializeToString,
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Entailments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.entailment.v1.EntailmentService/Entailments',
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsRequest.SerializeToString,
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
