"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.topic_modeling.v1.topic_modeling_pb2
import grpc

class TopicModelingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Topics: grpc.UnaryUnaryMultiCallable[
        arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsRequest,
        arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsResponse] = ...


class TopicModelingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Topics(self,
        request: arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsResponse: ...


def add_TopicModelingServiceServicer_to_server(servicer: TopicModelingServiceServicer, server: grpc.Server) -> None: ...
