"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.entailment.v1.entailment_pb2
import grpc

class EntailmentServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Entailment: grpc.UnaryUnaryMultiCallable[
        arg_services.entailment.v1.entailment_pb2.EntailmentRequest,
        arg_services.entailment.v1.entailment_pb2.EntailmentResponse] = ...

    Entailments: grpc.UnaryUnaryMultiCallable[
        arg_services.entailment.v1.entailment_pb2.EntailmentsRequest,
        arg_services.entailment.v1.entailment_pb2.EntailmentsResponse] = ...


class EntailmentServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Entailment(self,
        request: arg_services.entailment.v1.entailment_pb2.EntailmentRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.entailment.v1.entailment_pb2.EntailmentResponse: ...

    @abc.abstractmethod
    def Entailments(self,
        request: arg_services.entailment.v1.entailment_pb2.EntailmentsRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.entailment.v1.entailment_pb2.EntailmentsResponse: ...


def add_EntailmentServiceServicer_to_server(servicer: EntailmentServiceServicer, server: grpc.Server) -> None: ...
