# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/adu/v1/adu.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/adu/v1/adu.proto',
  package='arg_services.adu.v1',
  syntax='proto3',
  serialized_options=b'\n&de.uni_trier.recap.arg_services.adu.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x61rg_services/adu/v1/adu.proto\x12\x13\x61rg_services.adu.v1\"Z\n\x13SegmentationRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x35\n\x0bgranularity\x18\x02 \x01(\x0e\x32 .arg_services.adu.v1.Granularity\"(\n\x14SegmentationResponse\x12\x10\n\x08segments\x18\x01 \x03(\t\"^\n\x15\x43lassificationRequest\x12\x10\n\x08segments\x18\x01 \x03(\t\x12\x33\n\nclassifier\x18\x02 \x01(\x0e\x32\x1f.arg_services.adu.v1.Classifier\"R\n\x16\x43lassificationResponse\x12\x38\n\x08segments\x18\x01 \x03(\x0b\x32&.arg_services.adu.v1.ClassifiedSegment\"N\n\x11\x43lassifiedSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03\x61\x64u\x18\x02 \x01(\x08\x12\r\n\x05\x63laim\x18\x03 \x01(\x08\x12\x0f\n\x07premise\x18\x04 \x01(\x08*|\n\x0bGranularity\x12\x1b\n\x17GRANULARITY_UNSPECIFIED\x10\x00\x12\x18\n\x14GRANULARITY_SENTENCE\x10\x01\x12\x1b\n\x17GRANULARITY_SUBSENTENCE\x10\x02\x12\x19\n\x15GRANULARITY_PARAGRAPH\x10\x03*u\n\nClassifier\x12\x1a\n\x16\x43LASSIFIER_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43LASSIFIER_TWO_WAY\x10\x01\x12\x18\n\x14\x43LASSIFIER_THREE_WAY\x10\x02\x12\x19\n\x15\x43LASSIFIER_SEQUENTIAL\x10\x03\x32\xdc\x01\n\nAduService\x12\x63\n\x0cSegmentation\x12(.arg_services.adu.v1.SegmentationRequest\x1a).arg_services.adu.v1.SegmentationResponse\x12i\n\x0e\x43lassification\x12*.arg_services.adu.v1.ClassificationRequest\x1a+.arg_services.adu.v1.ClassificationResponseB(\n&de.uni_trier.recap.arg_services.adu.v1b\x06proto3'
)

_GRANULARITY = _descriptor.EnumDescriptor(
  name='Granularity',
  full_name='arg_services.adu.v1.Granularity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_SENTENCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_SUBSENTENCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_PARAGRAPH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=448,
  serialized_end=572,
)
_sym_db.RegisterEnumDescriptor(_GRANULARITY)

Granularity = enum_type_wrapper.EnumTypeWrapper(_GRANULARITY)
_CLASSIFIER = _descriptor.EnumDescriptor(
  name='Classifier',
  full_name='arg_services.adu.v1.Classifier',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_TWO_WAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_THREE_WAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_SEQUENTIAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=574,
  serialized_end=691,
)
_sym_db.RegisterEnumDescriptor(_CLASSIFIER)

Classifier = enum_type_wrapper.EnumTypeWrapper(_CLASSIFIER)
GRANULARITY_UNSPECIFIED = 0
GRANULARITY_SENTENCE = 1
GRANULARITY_SUBSENTENCE = 2
GRANULARITY_PARAGRAPH = 3
CLASSIFIER_UNSPECIFIED = 0
CLASSIFIER_TWO_WAY = 1
CLASSIFIER_THREE_WAY = 2
CLASSIFIER_SEQUENTIAL = 3



_SEGMENTATIONREQUEST = _descriptor.Descriptor(
  name='SegmentationRequest',
  full_name='arg_services.adu.v1.SegmentationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.adu.v1.SegmentationRequest.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granularity', full_name='arg_services.adu.v1.SegmentationRequest.granularity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=144,
)


_SEGMENTATIONRESPONSE = _descriptor.Descriptor(
  name='SegmentationResponse',
  full_name='arg_services.adu.v1.SegmentationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='arg_services.adu.v1.SegmentationResponse.segments', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=186,
)


_CLASSIFICATIONREQUEST = _descriptor.Descriptor(
  name='ClassificationRequest',
  full_name='arg_services.adu.v1.ClassificationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='arg_services.adu.v1.ClassificationRequest.segments', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifier', full_name='arg_services.adu.v1.ClassificationRequest.classifier', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=282,
)


_CLASSIFICATIONRESPONSE = _descriptor.Descriptor(
  name='ClassificationResponse',
  full_name='arg_services.adu.v1.ClassificationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='arg_services.adu.v1.ClassificationResponse.segments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=366,
)


_CLASSIFIEDSEGMENT = _descriptor.Descriptor(
  name='ClassifiedSegment',
  full_name='arg_services.adu.v1.ClassifiedSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.adu.v1.ClassifiedSegment.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adu', full_name='arg_services.adu.v1.ClassifiedSegment.adu', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim', full_name='arg_services.adu.v1.ClassifiedSegment.claim', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premise', full_name='arg_services.adu.v1.ClassifiedSegment.premise', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=446,
)

_SEGMENTATIONREQUEST.fields_by_name['granularity'].enum_type = _GRANULARITY
_CLASSIFICATIONREQUEST.fields_by_name['classifier'].enum_type = _CLASSIFIER
_CLASSIFICATIONRESPONSE.fields_by_name['segments'].message_type = _CLASSIFIEDSEGMENT
DESCRIPTOR.message_types_by_name['SegmentationRequest'] = _SEGMENTATIONREQUEST
DESCRIPTOR.message_types_by_name['SegmentationResponse'] = _SEGMENTATIONRESPONSE
DESCRIPTOR.message_types_by_name['ClassificationRequest'] = _CLASSIFICATIONREQUEST
DESCRIPTOR.message_types_by_name['ClassificationResponse'] = _CLASSIFICATIONRESPONSE
DESCRIPTOR.message_types_by_name['ClassifiedSegment'] = _CLASSIFIEDSEGMENT
DESCRIPTOR.enum_types_by_name['Granularity'] = _GRANULARITY
DESCRIPTOR.enum_types_by_name['Classifier'] = _CLASSIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SegmentationRequest = _reflection.GeneratedProtocolMessageType('SegmentationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTATIONREQUEST,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.SegmentationRequest)
  })
_sym_db.RegisterMessage(SegmentationRequest)

SegmentationResponse = _reflection.GeneratedProtocolMessageType('SegmentationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTATIONRESPONSE,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.SegmentationResponse)
  })
_sym_db.RegisterMessage(SegmentationResponse)

ClassificationRequest = _reflection.GeneratedProtocolMessageType('ClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFICATIONREQUEST,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.ClassificationRequest)
  })
_sym_db.RegisterMessage(ClassificationRequest)

ClassificationResponse = _reflection.GeneratedProtocolMessageType('ClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFICATIONRESPONSE,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.ClassificationResponse)
  })
_sym_db.RegisterMessage(ClassificationResponse)

ClassifiedSegment = _reflection.GeneratedProtocolMessageType('ClassifiedSegment', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFIEDSEGMENT,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.ClassifiedSegment)
  })
_sym_db.RegisterMessage(ClassifiedSegment)


DESCRIPTOR._options = None

_ADUSERVICE = _descriptor.ServiceDescriptor(
  name='AduService',
  full_name='arg_services.adu.v1.AduService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=694,
  serialized_end=914,
  methods=[
  _descriptor.MethodDescriptor(
    name='Segmentation',
    full_name='arg_services.adu.v1.AduService.Segmentation',
    index=0,
    containing_service=None,
    input_type=_SEGMENTATIONREQUEST,
    output_type=_SEGMENTATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Classification',
    full_name='arg_services.adu.v1.AduService.Classification',
    index=1,
    containing_service=None,
    input_type=_CLASSIFICATIONREQUEST,
    output_type=_CLASSIFICATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADUSERVICE)

DESCRIPTOR.services_by_name['AduService'] = _ADUSERVICE

# @@protoc_insertion_point(module_scope)
