# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/topic_modeling/v1/topic_modeling.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from arg_services.nlp.v1 import nlp_pb2 as arg__services_dot_nlp_dot_v1_dot_nlp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/topic_modeling/v1/topic_modeling.proto',
  package='arg_services.topic_modeling.v1',
  syntax='proto3',
  serialized_options=b'\n1de.uni_trier.recap.arg_services.topic_modeling.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3arg_services/topic_modeling/v1/topic_modeling.proto\x12\x1e\x61rg_services.topic_modeling.v1\x1a\x1d\x61rg_services/nlp/v1/nlp.proto\"R\n\rTopicsRequest\x12\x11\n\tdocuments\x18\x01 \x03(\t\x12.\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\"\x80\x01\n\x0eTopicsResponse\x12\x37\n\x08outliers\x18\x01 \x01(\x0b\x32%.arg_services.topic_modeling.v1.Topic\x12\x35\n\x06topics\x18\x02 \x03(\x0b\x32%.arg_services.topic_modeling.v1.Topic\"K\n\x05Topic\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x33\n\x05terms\x18\x02 \x03(\x0b\x32$.arg_services.topic_modeling.v1.Term\"#\n\x04Term\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x32\x7f\n\x14TopicModelingService\x12g\n\x06Topics\x12-.arg_services.topic_modeling.v1.TopicsRequest\x1a..arg_services.topic_modeling.v1.TopicsResponseB3\n1de.uni_trier.recap.arg_services.topic_modeling.v1b\x06proto3'
  ,
  dependencies=[arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DESCRIPTOR,])




_TOPICSREQUEST = _descriptor.Descriptor(
  name='TopicsRequest',
  full_name='arg_services.topic_modeling.v1.TopicsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='documents', full_name='arg_services.topic_modeling.v1.TopicsRequest.documents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.topic_modeling.v1.TopicsRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=200,
)


_TOPICSRESPONSE = _descriptor.Descriptor(
  name='TopicsResponse',
  full_name='arg_services.topic_modeling.v1.TopicsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outliers', full_name='arg_services.topic_modeling.v1.TopicsResponse.outliers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='arg_services.topic_modeling.v1.TopicsResponse.topics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=331,
)


_TOPIC = _descriptor.Descriptor(
  name='Topic',
  full_name='arg_services.topic_modeling.v1.Topic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='arg_services.topic_modeling.v1.Topic.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terms', full_name='arg_services.topic_modeling.v1.Topic.terms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=408,
)


_TERM = _descriptor.Descriptor(
  name='Term',
  full_name='arg_services.topic_modeling.v1.Term',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.topic_modeling.v1.Term.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='arg_services.topic_modeling.v1.Term.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=445,
)

_TOPICSREQUEST.fields_by_name['config'].message_type = arg__services_dot_nlp_dot_v1_dot_nlp__pb2._NLPCONFIG
_TOPICSRESPONSE.fields_by_name['outliers'].message_type = _TOPIC
_TOPICSRESPONSE.fields_by_name['topics'].message_type = _TOPIC
_TOPIC.fields_by_name['terms'].message_type = _TERM
DESCRIPTOR.message_types_by_name['TopicsRequest'] = _TOPICSREQUEST
DESCRIPTOR.message_types_by_name['TopicsResponse'] = _TOPICSRESPONSE
DESCRIPTOR.message_types_by_name['Topic'] = _TOPIC
DESCRIPTOR.message_types_by_name['Term'] = _TERM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicsRequest = _reflection.GeneratedProtocolMessageType('TopicsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSREQUEST,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.TopicsRequest)
  })
_sym_db.RegisterMessage(TopicsRequest)

TopicsResponse = _reflection.GeneratedProtocolMessageType('TopicsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSRESPONSE,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.TopicsResponse)
  })
_sym_db.RegisterMessage(TopicsResponse)

Topic = _reflection.GeneratedProtocolMessageType('Topic', (_message.Message,), {
  'DESCRIPTOR' : _TOPIC,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.Topic)
  })
_sym_db.RegisterMessage(Topic)

Term = _reflection.GeneratedProtocolMessageType('Term', (_message.Message,), {
  'DESCRIPTOR' : _TERM,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.Term)
  })
_sym_db.RegisterMessage(Term)


DESCRIPTOR._options = None

_TOPICMODELINGSERVICE = _descriptor.ServiceDescriptor(
  name='TopicModelingService',
  full_name='arg_services.topic_modeling.v1.TopicModelingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=447,
  serialized_end=574,
  methods=[
  _descriptor.MethodDescriptor(
    name='Topics',
    full_name='arg_services.topic_modeling.v1.TopicModelingService.Topics',
    index=0,
    containing_service=None,
    input_type=_TOPICSREQUEST,
    output_type=_TOPICSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TOPICMODELINGSERVICE)

DESCRIPTOR.services_by_name['TopicModelingService'] = _TOPICMODELINGSERVICE

# @@protoc_insertion_point(module_scope)
