# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/entailment/v1/entailment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/entailment/v1/entailment.proto',
  package='arg_services.entailment.v1',
  syntax='proto3',
  serialized_options=b'\n-de.uni_trier.recap.arg_services.entailment.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+arg_services/entailment/v1/entailment.proto\x12\x1a\x61rg_services.entailment.v1\"E\n\x11\x45ntailmentRequest\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0f\n\x07premise\x18\x02 \x01(\t\x12\r\n\x05\x63laim\x18\x03 \x01(\t\"T\n\x12\x45ntailmentsRequest\x12>\n\x07queries\x18\x01 \x03(\x0b\x32-.arg_services.entailment.v1.EntailmentRequest\"\x85\x01\n\x12\x45ntailmentResponse\x12:\n\nprediction\x18\x01 \x01(\x0e\x32&.arg_services.entailment.v1.Prediction\x12\x33\n\x07\x64\x65tails\x18\x02 \x03(\x0b\x32\".arg_services.entailment.v1.Detail\"V\n\x13\x45ntailmentsResponse\x12?\n\x07results\x18\x01 \x03(\x0b\x32..arg_services.entailment.v1.EntailmentResponse\"Y\n\x06\x44\x65tail\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12:\n\nprediction\x18\x02 \x01(\x0e\x32&.arg_services.entailment.v1.Prediction*y\n\nPrediction\x12\x1a\n\x16PREDICTION_UNSPECIFIED\x10\x00\x12\x19\n\x15PREDICTION_ENTAILMENT\x10\x01\x12\x1c\n\x18PREDICTION_CONTRADICTION\x10\x02\x12\x16\n\x12PREDICTION_NEUTRAL\x10\x03\x32\xf0\x01\n\x11\x45ntailmentService\x12k\n\nEntailment\x12-.arg_services.entailment.v1.EntailmentRequest\x1a..arg_services.entailment.v1.EntailmentResponse\x12n\n\x0b\x45ntailments\x12..arg_services.entailment.v1.EntailmentsRequest\x1a/.arg_services.entailment.v1.EntailmentsResponseB/\n-de.uni_trier.recap.arg_services.entailment.v1b\x06proto3'
)

_PREDICTION = _descriptor.EnumDescriptor(
  name='Prediction',
  full_name='arg_services.entailment.v1.Prediction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_ENTAILMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_CONTRADICTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_NEUTRAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=547,
  serialized_end=668,
)
_sym_db.RegisterEnumDescriptor(_PREDICTION)

Prediction = enum_type_wrapper.EnumTypeWrapper(_PREDICTION)
PREDICTION_UNSPECIFIED = 0
PREDICTION_ENTAILMENT = 1
PREDICTION_CONTRADICTION = 2
PREDICTION_NEUTRAL = 3



_ENTAILMENTREQUEST = _descriptor.Descriptor(
  name='EntailmentRequest',
  full_name='arg_services.entailment.v1.EntailmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='arg_services.entailment.v1.EntailmentRequest.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premise', full_name='arg_services.entailment.v1.EntailmentRequest.premise', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim', full_name='arg_services.entailment.v1.EntailmentRequest.claim', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=144,
)


_ENTAILMENTSREQUEST = _descriptor.Descriptor(
  name='EntailmentsRequest',
  full_name='arg_services.entailment.v1.EntailmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queries', full_name='arg_services.entailment.v1.EntailmentsRequest.queries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=230,
)


_ENTAILMENTRESPONSE = _descriptor.Descriptor(
  name='EntailmentResponse',
  full_name='arg_services.entailment.v1.EntailmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction', full_name='arg_services.entailment.v1.EntailmentResponse.prediction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='arg_services.entailment.v1.EntailmentResponse.details', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=366,
)


_ENTAILMENTSRESPONSE = _descriptor.Descriptor(
  name='EntailmentsResponse',
  full_name='arg_services.entailment.v1.EntailmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='arg_services.entailment.v1.EntailmentsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=454,
)


_DETAIL = _descriptor.Descriptor(
  name='Detail',
  full_name='arg_services.entailment.v1.Detail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='arg_services.entailment.v1.Detail.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction', full_name='arg_services.entailment.v1.Detail.prediction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=545,
)

_ENTAILMENTSREQUEST.fields_by_name['queries'].message_type = _ENTAILMENTREQUEST
_ENTAILMENTRESPONSE.fields_by_name['prediction'].enum_type = _PREDICTION
_ENTAILMENTRESPONSE.fields_by_name['details'].message_type = _DETAIL
_ENTAILMENTSRESPONSE.fields_by_name['results'].message_type = _ENTAILMENTRESPONSE
_DETAIL.fields_by_name['prediction'].enum_type = _PREDICTION
DESCRIPTOR.message_types_by_name['EntailmentRequest'] = _ENTAILMENTREQUEST
DESCRIPTOR.message_types_by_name['EntailmentsRequest'] = _ENTAILMENTSREQUEST
DESCRIPTOR.message_types_by_name['EntailmentResponse'] = _ENTAILMENTRESPONSE
DESCRIPTOR.message_types_by_name['EntailmentsResponse'] = _ENTAILMENTSRESPONSE
DESCRIPTOR.message_types_by_name['Detail'] = _DETAIL
DESCRIPTOR.enum_types_by_name['Prediction'] = _PREDICTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EntailmentRequest = _reflection.GeneratedProtocolMessageType('EntailmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTREQUEST,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentRequest)
  })
_sym_db.RegisterMessage(EntailmentRequest)

EntailmentsRequest = _reflection.GeneratedProtocolMessageType('EntailmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTSREQUEST,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentsRequest)
  })
_sym_db.RegisterMessage(EntailmentsRequest)

EntailmentResponse = _reflection.GeneratedProtocolMessageType('EntailmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTRESPONSE,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentResponse)
  })
_sym_db.RegisterMessage(EntailmentResponse)

EntailmentsResponse = _reflection.GeneratedProtocolMessageType('EntailmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENTAILMENTSRESPONSE,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.EntailmentsResponse)
  })
_sym_db.RegisterMessage(EntailmentsResponse)

Detail = _reflection.GeneratedProtocolMessageType('Detail', (_message.Message,), {
  'DESCRIPTOR' : _DETAIL,
  '__module__' : 'arg_services.entailment.v1.entailment_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.entailment.v1.Detail)
  })
_sym_db.RegisterMessage(Detail)


DESCRIPTOR._options = None

_ENTAILMENTSERVICE = _descriptor.ServiceDescriptor(
  name='EntailmentService',
  full_name='arg_services.entailment.v1.EntailmentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=671,
  serialized_end=911,
  methods=[
  _descriptor.MethodDescriptor(
    name='Entailment',
    full_name='arg_services.entailment.v1.EntailmentService.Entailment',
    index=0,
    containing_service=None,
    input_type=_ENTAILMENTREQUEST,
    output_type=_ENTAILMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Entailments',
    full_name='arg_services.entailment.v1.EntailmentService.Entailments',
    index=1,
    containing_service=None,
    input_type=_ENTAILMENTSREQUEST,
    output_type=_ENTAILMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENTAILMENTSERVICE)

DESCRIPTOR.services_by_name['EntailmentService'] = _ENTAILMENTSERVICE

# @@protoc_insertion_point(module_scope)
