"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.adu.v1.adu_pb2
import grpc

class AduServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Segmentation: grpc.UnaryUnaryMultiCallable[
        arg_services.adu.v1.adu_pb2.SegmentationRequest,
        arg_services.adu.v1.adu_pb2.SegmentationResponse] = ...

    Classification: grpc.UnaryUnaryMultiCallable[
        arg_services.adu.v1.adu_pb2.ClassificationRequest,
        arg_services.adu.v1.adu_pb2.ClassificationResponse] = ...
    """rpc TwoWay (TwoWayRequest) returns (TwoWayResponse);
    rpc ThreeWay (ThreeWayRequest) returns (ThreeWayResponse);
    rpc Sequential (SequentialRequest) returns (SequentialResponse);
    """


class AduServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Segmentation(self,
        request: arg_services.adu.v1.adu_pb2.SegmentationRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.adu.v1.adu_pb2.SegmentationResponse: ...

    @abc.abstractmethod
    def Classification(self,
        request: arg_services.adu.v1.adu_pb2.ClassificationRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.adu.v1.adu_pb2.ClassificationResponse:
        """rpc TwoWay (TwoWayRequest) returns (TwoWayResponse);
        rpc ThreeWay (ThreeWayRequest) returns (ThreeWayResponse);
        rpc Sequential (SequentialRequest) returns (SequentialResponse);
        """
        pass


def add_AduServiceServicer_to_server(servicer: AduServiceServicer, server: grpc.Server) -> None: ...
