# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/retrieval/v1/retrieval.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from arg_services.graph.v1 import graph_pb2 as arg__services_dot_graph_dot_v1_dot_graph__pb2
from arg_services.nlp.v1 import nlp_pb2 as arg__services_dot_nlp_dot_v1_dot_nlp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/retrieval/v1/retrieval.proto',
  package='arg_services.retrieval.v1',
  syntax='proto3',
  serialized_options=b'\n,de.uni_trier.recap.arg_services.retrieval.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)arg_services/retrieval/v1/retrieval.proto\x12\x19\x61rg_services.retrieval.v1\x1a!arg_services/graph/v1/graph.proto\x1a\x1d\x61rg_services/nlp/v1/nlp.proto\"\xe3\x03\n\x0fRetrieveRequest\x12\x44\n\x05\x63\x61ses\x18\x01 \x03(\x0b\x32\x35.arg_services.retrieval.v1.RetrieveRequest.CasesEntry\x12\x33\n\x0bquery_graph\x18\x02 \x01(\x0b\x32\x1c.arg_services.graph.v1.GraphH\x00\x12\x14\n\nquery_text\x18\x03 \x01(\tH\x00\x12\x32\n\nnlp_config\x18\x04 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x11\n\tmac_phase\x18\x06 \x01(\x08\x12\x11\n\tfac_phase\x18\x07 \x01(\x08\x12\x46\n\x11mapping_algorithm\x18\x08 \x01(\x0e\x32+.arg_services.retrieval.v1.MappingAlgorithm\x12\x1b\n\x13use_scheme_ontology\x18\t \x01(\x08\x12\x1c\n\x14\x65nforce_scheme_types\x18\n \x01(\x08\x1aJ\n\nCasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.arg_services.graph.v1.Graph:\x02\x38\x01\x42\x07\n\x05query\"\xce\x01\n\x10RetrieveResponse\x12\x39\n\x07ranking\x18\x01 \x03(\x0b\x32(.arg_services.retrieval.v1.RetrievedCase\x12=\n\x0bmac_ranking\x18\x02 \x03(\x0b\x32(.arg_services.retrieval.v1.RetrievedCase\x12@\n\x0b\x66\x61\x63_ranking\x18\x03 \x03(\x0b\x32+.arg_services.retrieval.v1.RetrievedMapping\"/\n\rRetrievedCase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsimilarity\x18\x02 \x01(\x01\"\x85\x01\n\x10RetrievedMapping\x12\x36\n\x04\x63\x61se\x18\x01 \x01(\x0b\x32(.arg_services.retrieval.v1.RetrievedCase\x12\x39\n\rnode_mappings\x18\x02 \x03(\x0b\x32\".arg_services.retrieval.v1.Mapping\"@\n\x07Mapping\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\t\x12\x12\n\nsimilarity\x18\x03 \x01(\x01*u\n\x10MappingAlgorithm\x12!\n\x1dMAPPING_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1b\n\x17MAPPING_ALGORITHM_ASTAR\x10\x01\x12!\n\x1dMAPPING_ALGORITHM_ISOMORPHISM\x10\x02\x32w\n\x10RetrievalService\x12\x63\n\x08Retrieve\x12*.arg_services.retrieval.v1.RetrieveRequest\x1a+.arg_services.retrieval.v1.RetrieveResponseB.\n,de.uni_trier.recap.arg_services.retrieval.v1b\x06proto3'
  ,
  dependencies=[arg__services_dot_graph_dot_v1_dot_graph__pb2.DESCRIPTOR,arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DESCRIPTOR,])

_MAPPINGALGORITHM = _descriptor.EnumDescriptor(
  name='MappingAlgorithm',
  full_name='arg_services.retrieval.v1.MappingAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAPPING_ALGORITHM_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAPPING_ALGORITHM_ASTAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAPPING_ALGORITHM_ISOMORPHISM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1084,
  serialized_end=1201,
)
_sym_db.RegisterEnumDescriptor(_MAPPINGALGORITHM)

MappingAlgorithm = enum_type_wrapper.EnumTypeWrapper(_MAPPINGALGORITHM)
MAPPING_ALGORITHM_UNSPECIFIED = 0
MAPPING_ALGORITHM_ASTAR = 1
MAPPING_ALGORITHM_ISOMORPHISM = 2



_RETRIEVEREQUEST_CASESENTRY = _descriptor.Descriptor(
  name='CasesEntry',
  full_name='arg_services.retrieval.v1.RetrieveRequest.CasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='arg_services.retrieval.v1.RetrieveRequest.CasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='arg_services.retrieval.v1.RetrieveRequest.CasesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=613,
)

_RETRIEVEREQUEST = _descriptor.Descriptor(
  name='RetrieveRequest',
  full_name='arg_services.retrieval.v1.RetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cases', full_name='arg_services.retrieval.v1.RetrieveRequest.cases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_graph', full_name='arg_services.retrieval.v1.RetrieveRequest.query_graph', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_text', full_name='arg_services.retrieval.v1.RetrieveRequest.query_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nlp_config', full_name='arg_services.retrieval.v1.RetrieveRequest.nlp_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='arg_services.retrieval.v1.RetrieveRequest.limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_phase', full_name='arg_services.retrieval.v1.RetrieveRequest.mac_phase', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fac_phase', full_name='arg_services.retrieval.v1.RetrieveRequest.fac_phase', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping_algorithm', full_name='arg_services.retrieval.v1.RetrieveRequest.mapping_algorithm', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_scheme_ontology', full_name='arg_services.retrieval.v1.RetrieveRequest.use_scheme_ontology', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforce_scheme_types', full_name='arg_services.retrieval.v1.RetrieveRequest.enforce_scheme_types', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRIEVEREQUEST_CASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='arg_services.retrieval.v1.RetrieveRequest.query',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=139,
  serialized_end=622,
)


_RETRIEVERESPONSE = _descriptor.Descriptor(
  name='RetrieveResponse',
  full_name='arg_services.retrieval.v1.RetrieveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranking', full_name='arg_services.retrieval.v1.RetrieveResponse.ranking', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_ranking', full_name='arg_services.retrieval.v1.RetrieveResponse.mac_ranking', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fac_ranking', full_name='arg_services.retrieval.v1.RetrieveResponse.fac_ranking', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=831,
)


_RETRIEVEDCASE = _descriptor.Descriptor(
  name='RetrievedCase',
  full_name='arg_services.retrieval.v1.RetrievedCase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='arg_services.retrieval.v1.RetrievedCase.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='similarity', full_name='arg_services.retrieval.v1.RetrievedCase.similarity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=880,
)


_RETRIEVEDMAPPING = _descriptor.Descriptor(
  name='RetrievedMapping',
  full_name='arg_services.retrieval.v1.RetrievedMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case', full_name='arg_services.retrieval.v1.RetrievedMapping.case', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_mappings', full_name='arg_services.retrieval.v1.RetrievedMapping.node_mappings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1016,
)


_MAPPING = _descriptor.Descriptor(
  name='Mapping',
  full_name='arg_services.retrieval.v1.Mapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='arg_services.retrieval.v1.Mapping.query_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_id', full_name='arg_services.retrieval.v1.Mapping.case_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='similarity', full_name='arg_services.retrieval.v1.Mapping.similarity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1082,
)

_RETRIEVEREQUEST_CASESENTRY.fields_by_name['value'].message_type = arg__services_dot_graph_dot_v1_dot_graph__pb2._GRAPH
_RETRIEVEREQUEST_CASESENTRY.containing_type = _RETRIEVEREQUEST
_RETRIEVEREQUEST.fields_by_name['cases'].message_type = _RETRIEVEREQUEST_CASESENTRY
_RETRIEVEREQUEST.fields_by_name['query_graph'].message_type = arg__services_dot_graph_dot_v1_dot_graph__pb2._GRAPH
_RETRIEVEREQUEST.fields_by_name['nlp_config'].message_type = arg__services_dot_nlp_dot_v1_dot_nlp__pb2._NLPCONFIG
_RETRIEVEREQUEST.fields_by_name['mapping_algorithm'].enum_type = _MAPPINGALGORITHM
_RETRIEVEREQUEST.oneofs_by_name['query'].fields.append(
  _RETRIEVEREQUEST.fields_by_name['query_graph'])
_RETRIEVEREQUEST.fields_by_name['query_graph'].containing_oneof = _RETRIEVEREQUEST.oneofs_by_name['query']
_RETRIEVEREQUEST.oneofs_by_name['query'].fields.append(
  _RETRIEVEREQUEST.fields_by_name['query_text'])
_RETRIEVEREQUEST.fields_by_name['query_text'].containing_oneof = _RETRIEVEREQUEST.oneofs_by_name['query']
_RETRIEVERESPONSE.fields_by_name['ranking'].message_type = _RETRIEVEDCASE
_RETRIEVERESPONSE.fields_by_name['mac_ranking'].message_type = _RETRIEVEDCASE
_RETRIEVERESPONSE.fields_by_name['fac_ranking'].message_type = _RETRIEVEDMAPPING
_RETRIEVEDMAPPING.fields_by_name['case'].message_type = _RETRIEVEDCASE
_RETRIEVEDMAPPING.fields_by_name['node_mappings'].message_type = _MAPPING
DESCRIPTOR.message_types_by_name['RetrieveRequest'] = _RETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['RetrieveResponse'] = _RETRIEVERESPONSE
DESCRIPTOR.message_types_by_name['RetrievedCase'] = _RETRIEVEDCASE
DESCRIPTOR.message_types_by_name['RetrievedMapping'] = _RETRIEVEDMAPPING
DESCRIPTOR.message_types_by_name['Mapping'] = _MAPPING
DESCRIPTOR.enum_types_by_name['MappingAlgorithm'] = _MAPPINGALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RetrieveRequest = _reflection.GeneratedProtocolMessageType('RetrieveRequest', (_message.Message,), {

  'CasesEntry' : _reflection.GeneratedProtocolMessageType('CasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RETRIEVEREQUEST_CASESENTRY,
    '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
    # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrieveRequest.CasesEntry)
    })
  ,
  'DESCRIPTOR' : _RETRIEVEREQUEST,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrieveRequest)
  })
_sym_db.RegisterMessage(RetrieveRequest)
_sym_db.RegisterMessage(RetrieveRequest.CasesEntry)

RetrieveResponse = _reflection.GeneratedProtocolMessageType('RetrieveResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVERESPONSE,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrieveResponse)
  })
_sym_db.RegisterMessage(RetrieveResponse)

RetrievedCase = _reflection.GeneratedProtocolMessageType('RetrievedCase', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDCASE,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrievedCase)
  })
_sym_db.RegisterMessage(RetrievedCase)

RetrievedMapping = _reflection.GeneratedProtocolMessageType('RetrievedMapping', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDMAPPING,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.RetrievedMapping)
  })
_sym_db.RegisterMessage(RetrievedMapping)

Mapping = _reflection.GeneratedProtocolMessageType('Mapping', (_message.Message,), {
  'DESCRIPTOR' : _MAPPING,
  '__module__' : 'arg_services.retrieval.v1.retrieval_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.retrieval.v1.Mapping)
  })
_sym_db.RegisterMessage(Mapping)


DESCRIPTOR._options = None
_RETRIEVEREQUEST_CASESENTRY._options = None

_RETRIEVALSERVICE = _descriptor.ServiceDescriptor(
  name='RetrievalService',
  full_name='arg_services.retrieval.v1.RetrievalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1203,
  serialized_end=1322,
  methods=[
  _descriptor.MethodDescriptor(
    name='Retrieve',
    full_name='arg_services.retrieval.v1.RetrievalService.Retrieve',
    index=0,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_RETRIEVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RETRIEVALSERVICE)

DESCRIPTOR.services_by_name['RetrievalService'] = _RETRIEVALSERVICE

# @@protoc_insertion_point(module_scope)
