"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import arg_services.nlp.v1.nlp_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TopicsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DOCUMENTS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def documents(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def config(self) -> arg_services.nlp.v1.nlp_pb2.NlpConfig: ...
    def __init__(self,
        *,
        documents : typing.Optional[typing.Iterable[typing.Text]] = ...,
        config : typing.Optional[arg_services.nlp.v1.nlp_pb2.NlpConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"documents",b"documents"]) -> None: ...
global___TopicsRequest = TopicsRequest

class TopicsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OUTLIERS_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    @property
    def outliers(self) -> global___Topic: ...
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Topic]: ...
    def __init__(self,
        *,
        outliers : typing.Optional[global___Topic] = ...,
        topics : typing.Optional[typing.Iterable[global___Topic]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"outliers",b"outliers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"outliers",b"outliers",u"topics",b"topics"]) -> None: ...
global___TopicsResponse = TopicsResponse

class Topic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COUNT_FIELD_NUMBER: builtins.int
    TERMS_FIELD_NUMBER: builtins.int
    count: builtins.int = ...
    @property
    def terms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Term]: ...
    def __init__(self,
        *,
        count : builtins.int = ...,
        terms : typing.Optional[typing.Iterable[global___Term]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"count",b"count",u"terms",b"terms"]) -> None: ...
global___Topic = Topic

class Term(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    score: builtins.float = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        score : builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"score",b"score",u"text",b"text"]) -> None: ...
global___Term = Term
