"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Granularity(_Granularity, metaclass=_GranularityEnumTypeWrapper):
    pass
class _Granularity:
    V = typing.NewType('V', builtins.int)
class _GranularityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Granularity.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    GRANULARITY_UNSPECIFIED = Granularity.V(0)
    GRANULARITY_SENTENCE = Granularity.V(1)
    GRANULARITY_SUBSENTENCE = Granularity.V(2)
    GRANULARITY_PARAGRAPH = Granularity.V(3)

GRANULARITY_UNSPECIFIED = Granularity.V(0)
GRANULARITY_SENTENCE = Granularity.V(1)
GRANULARITY_SUBSENTENCE = Granularity.V(2)
GRANULARITY_PARAGRAPH = Granularity.V(3)
global___Granularity = Granularity


class Classifier(_Classifier, metaclass=_ClassifierEnumTypeWrapper):
    pass
class _Classifier:
    V = typing.NewType('V', builtins.int)
class _ClassifierEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Classifier.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    CLASSIFIER_UNSPECIFIED = Classifier.V(0)
    CLASSIFIER_TWO_WAY = Classifier.V(1)
    CLASSIFIER_THREE_WAY = Classifier.V(2)
    CLASSIFIER_SEQUENTIAL = Classifier.V(3)

CLASSIFIER_UNSPECIFIED = Classifier.V(0)
CLASSIFIER_TWO_WAY = Classifier.V(1)
CLASSIFIER_THREE_WAY = Classifier.V(2)
CLASSIFIER_SEQUENTIAL = Classifier.V(3)
global___Classifier = Classifier


class SegmentationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    GRANULARITY_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    granularity: global___Granularity.V = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        granularity : global___Granularity.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"granularity",b"granularity",u"text",b"text"]) -> None: ...
global___SegmentationRequest = SegmentationRequest

class SegmentationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        segments : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"segments",b"segments"]) -> None: ...
global___SegmentationResponse = SegmentationResponse

class ClassificationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEGMENTS_FIELD_NUMBER: builtins.int
    CLASSIFIER_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    classifier: global___Classifier.V = ...
    def __init__(self,
        *,
        segments : typing.Optional[typing.Iterable[typing.Text]] = ...,
        classifier : global___Classifier.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"classifier",b"classifier",u"segments",b"segments"]) -> None: ...
global___ClassificationRequest = ClassificationRequest

class ClassificationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClassifiedSegment]: ...
    def __init__(self,
        *,
        segments : typing.Optional[typing.Iterable[global___ClassifiedSegment]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"segments",b"segments"]) -> None: ...
global___ClassificationResponse = ClassificationResponse

class ClassifiedSegment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    ADU_FIELD_NUMBER: builtins.int
    CLAIM_FIELD_NUMBER: builtins.int
    PREMISE_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    adu: builtins.bool = ...
    claim: builtins.bool = ...
    premise: builtins.bool = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        adu : builtins.bool = ...,
        claim : builtins.bool = ...,
        premise : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"adu",b"adu",u"claim",b"claim",u"premise",b"premise",u"text",b"text"]) -> None: ...
global___ClassifiedSegment = ClassifiedSegment
