"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.retrieval.v1.retrieval_pb2
import grpc

class RetrievalServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Retrieve: grpc.UnaryUnaryMultiCallable[
        arg_services.retrieval.v1.retrieval_pb2.RetrieveRequest,
        arg_services.retrieval.v1.retrieval_pb2.RetrieveResponse] = ...


class RetrievalServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Retrieve(self,
        request: arg_services.retrieval.v1.retrieval_pb2.RetrieveRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.retrieval.v1.retrieval_pb2.RetrieveResponse: ...


def add_RetrievalServiceServicer_to_server(servicer: RetrievalServiceServicer, server: grpc.Server) -> None: ...
