"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Prediction(_Prediction, metaclass=_PredictionEnumTypeWrapper):
    pass
class _Prediction:
    V = typing.NewType('V', builtins.int)
class _PredictionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Prediction.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    PREDICTION_UNSPECIFIED = Prediction.V(0)
    PREDICTION_ENTAILMENT = Prediction.V(1)
    PREDICTION_CONTRADICTION = Prediction.V(2)
    PREDICTION_NEUTRAL = Prediction.V(3)

PREDICTION_UNSPECIFIED = Prediction.V(0)
PREDICTION_ENTAILMENT = Prediction.V(1)
PREDICTION_CONTRADICTION = Prediction.V(2)
PREDICTION_NEUTRAL = Prediction.V(3)
global___Prediction = Prediction


class EntailmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LANGUAGE_FIELD_NUMBER: builtins.int
    PREMISE_FIELD_NUMBER: builtins.int
    CLAIM_FIELD_NUMBER: builtins.int
    language: typing.Text = ...
    premise: typing.Text = ...
    claim: typing.Text = ...
    def __init__(self,
        *,
        language : typing.Text = ...,
        premise : typing.Text = ...,
        claim : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"claim",b"claim",u"language",b"language",u"premise",b"premise"]) -> None: ...
global___EntailmentRequest = EntailmentRequest

class EntailmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntailmentRequest]: ...
    def __init__(self,
        *,
        queries : typing.Optional[typing.Iterable[global___EntailmentRequest]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"queries",b"queries"]) -> None: ...
global___EntailmentsRequest = EntailmentsRequest

class EntailmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PREDICTION_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    prediction: global___Prediction.V = ...
    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Detail]: ...
    def __init__(self,
        *,
        prediction : global___Prediction.V = ...,
        details : typing.Optional[typing.Iterable[global___Detail]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"details",b"details",u"prediction",b"prediction"]) -> None: ...
global___EntailmentResponse = EntailmentResponse

class EntailmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntailmentResponse]: ...
    def __init__(self,
        *,
        results : typing.Optional[typing.Iterable[global___EntailmentResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"results",b"results"]) -> None: ...
global___EntailmentsResponse = EntailmentsResponse

class Detail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROBABILITY_FIELD_NUMBER: builtins.int
    PREDICTION_FIELD_NUMBER: builtins.int
    probability: builtins.float = ...
    prediction: global___Prediction.V = ...
    def __init__(self,
        *,
        probability : builtins.float = ...,
        prediction : global___Prediction.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"prediction",b"prediction",u"probability",b"probability"]) -> None: ...
global___Detail = Detail
